==> haskell-hedgehog-0.6.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-HCmnRuPW8FEGpPLSuFGSNM
key: hedgehog-0.6.1-HCmnRuPW8FEGpPLSuFGSNM
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: d60717350a4d935781e520e84019285a
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.2/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-HCmnRuPW8FEGpPLSuFGSNM
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 concurrent-output-1.10.7-EEZsmJQDX8axX6hTVsHbN
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH
    lifted-async-0.10.0.3-18gQCElKStkELGCaqZZTIG
    mmorph-1.1.2-1XKbJejgVfn63jvndItiSw
    monad-control-1.0.2.3-7SVvmdRNlJOIZktsz9GGO0 mtl-2.2.2
    pretty-show-1.8.2-9jEbyeGmQQKEYhlVpZDwWd
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-841yAQBgNwO7J9O4S3A6Ce stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-LnTGoHqCWSE8c71m7nk0Lo unix-2.7.2.2
    wl-pprint-annotated-0.1.0.1-Fpfa7ZZCgs3Ks5C7uKmJgp
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-0.6.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-1Xd7dRVe1oL8McmZKngNrr
key: hedgehog-0.6.1-1Xd7dRVe1oL8McmZKngNrr
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: 73def8d360c6d3d37c745a0e42360ae1
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.2/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-1Xd7dRVe1oL8McmZKngNrr
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 concurrent-output-1.10.9-CAcm3BHmt1TDrPG9aKR8C4
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH
    lifted-async-0.10.0.3-18gQCElKStkELGCaqZZTIG
    mmorph-1.1.2-1XKbJejgVfn63jvndItiSw
    monad-control-1.0.2.3-7SVvmdRNlJOIZktsz9GGO0 mtl-2.2.2
    pretty-show-1.8.2-9jEbyeGmQQKEYhlVpZDwWd
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-841yAQBgNwO7J9O4S3A6Ce stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-LnTGoHqCWSE8c71m7nk0Lo unix-2.7.2.2
    wl-pprint-annotated-0.1.0.1-Fpfa7ZZCgs3Ks5C7uKmJgp
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
